import type { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PopulatedTransaction, Signer, utils } from "ethers";
import type { FunctionFragment, Result, EventFragment } from "@ethersproject/abi";
import type { Listener, Provider } from "@ethersproject/providers";
import type { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "./common.js";
export interface IStaking1155Interface extends utils.Interface {
    functions: {
        "claimRewards(uint256)": FunctionFragment;
        "getStakeInfo(address)": FunctionFragment;
        "getStakeInfoForToken(uint256,address)": FunctionFragment;
        "stake(uint256,uint64)": FunctionFragment;
        "withdraw(uint256,uint64)": FunctionFragment;
    };
    getFunction(nameOrSignatureOrTopic: "claimRewards" | "getStakeInfo" | "getStakeInfoForToken" | "stake" | "withdraw"): FunctionFragment;
    encodeFunctionData(functionFragment: "claimRewards", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "getStakeInfo", values: [string]): string;
    encodeFunctionData(functionFragment: "getStakeInfoForToken", values: [BigNumberish, string]): string;
    encodeFunctionData(functionFragment: "stake", values: [BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "withdraw", values: [BigNumberish, BigNumberish]): string;
    decodeFunctionResult(functionFragment: "claimRewards", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getStakeInfo", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getStakeInfoForToken", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "stake", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "withdraw", data: BytesLike): Result;
    events: {
        "RewardsClaimed(address,uint256)": EventFragment;
        "TokensStaked(address,uint256,uint256)": EventFragment;
        "TokensWithdrawn(address,uint256,uint256)": EventFragment;
        "UpdatedDefaultRewardsPerUnitTime(uint256,uint256)": EventFragment;
        "UpdatedDefaultTimeUnit(uint256,uint256)": EventFragment;
        "UpdatedRewardsPerUnitTime(uint256,uint256,uint256)": EventFragment;
        "UpdatedTimeUnit(uint256,uint256,uint256)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "RewardsClaimed"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "TokensStaked"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "TokensWithdrawn"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "UpdatedDefaultRewardsPerUnitTime"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "UpdatedDefaultTimeUnit"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "UpdatedRewardsPerUnitTime"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "UpdatedTimeUnit"): EventFragment;
}
export interface RewardsClaimedEventObject {
    staker: string;
    rewardAmount: BigNumber;
}
export type RewardsClaimedEvent = TypedEvent<[
    string,
    BigNumber
], RewardsClaimedEventObject>;
export type RewardsClaimedEventFilter = TypedEventFilter<RewardsClaimedEvent>;
export interface TokensStakedEventObject {
    staker: string;
    tokenId: BigNumber;
    amount: BigNumber;
}
export type TokensStakedEvent = TypedEvent<[
    string,
    BigNumber,
    BigNumber
], TokensStakedEventObject>;
export type TokensStakedEventFilter = TypedEventFilter<TokensStakedEvent>;
export interface TokensWithdrawnEventObject {
    staker: string;
    tokenId: BigNumber;
    amount: BigNumber;
}
export type TokensWithdrawnEvent = TypedEvent<[
    string,
    BigNumber,
    BigNumber
], TokensWithdrawnEventObject>;
export type TokensWithdrawnEventFilter = TypedEventFilter<TokensWithdrawnEvent>;
export interface UpdatedDefaultRewardsPerUnitTimeEventObject {
    oldRewardsPerUnitTime: BigNumber;
    newRewardsPerUnitTime: BigNumber;
}
export type UpdatedDefaultRewardsPerUnitTimeEvent = TypedEvent<[
    BigNumber,
    BigNumber
], UpdatedDefaultRewardsPerUnitTimeEventObject>;
export type UpdatedDefaultRewardsPerUnitTimeEventFilter = TypedEventFilter<UpdatedDefaultRewardsPerUnitTimeEvent>;
export interface UpdatedDefaultTimeUnitEventObject {
    oldTimeUnit: BigNumber;
    newTimeUnit: BigNumber;
}
export type UpdatedDefaultTimeUnitEvent = TypedEvent<[
    BigNumber,
    BigNumber
], UpdatedDefaultTimeUnitEventObject>;
export type UpdatedDefaultTimeUnitEventFilter = TypedEventFilter<UpdatedDefaultTimeUnitEvent>;
export interface UpdatedRewardsPerUnitTimeEventObject {
    _tokenId: BigNumber;
    oldRewardsPerUnitTime: BigNumber;
    newRewardsPerUnitTime: BigNumber;
}
export type UpdatedRewardsPerUnitTimeEvent = TypedEvent<[
    BigNumber,
    BigNumber,
    BigNumber
], UpdatedRewardsPerUnitTimeEventObject>;
export type UpdatedRewardsPerUnitTimeEventFilter = TypedEventFilter<UpdatedRewardsPerUnitTimeEvent>;
export interface UpdatedTimeUnitEventObject {
    _tokenId: BigNumber;
    oldTimeUnit: BigNumber;
    newTimeUnit: BigNumber;
}
export type UpdatedTimeUnitEvent = TypedEvent<[
    BigNumber,
    BigNumber,
    BigNumber
], UpdatedTimeUnitEventObject>;
export type UpdatedTimeUnitEventFilter = TypedEventFilter<UpdatedTimeUnitEvent>;
export interface IStaking1155 extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: IStaking1155Interface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        claimRewards(tokenId: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        getStakeInfo(staker: string, overrides?: CallOverrides): Promise<[
            BigNumber[],
            BigNumber[],
            BigNumber
        ] & {
            _tokensStaked: BigNumber[];
            _tokenAmounts: BigNumber[];
            _totalRewards: BigNumber;
        }>;
        getStakeInfoForToken(tokenId: BigNumberish, staker: string, overrides?: CallOverrides): Promise<[
            BigNumber,
            BigNumber
        ] & {
            _tokensStaked: BigNumber;
            _rewards: BigNumber;
        }>;
        stake(tokenId: BigNumberish, amount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        withdraw(tokenId: BigNumberish, amount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
    };
    claimRewards(tokenId: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    getStakeInfo(staker: string, overrides?: CallOverrides): Promise<[
        BigNumber[],
        BigNumber[],
        BigNumber
    ] & {
        _tokensStaked: BigNumber[];
        _tokenAmounts: BigNumber[];
        _totalRewards: BigNumber;
    }>;
    getStakeInfoForToken(tokenId: BigNumberish, staker: string, overrides?: CallOverrides): Promise<[
        BigNumber,
        BigNumber
    ] & {
        _tokensStaked: BigNumber;
        _rewards: BigNumber;
    }>;
    stake(tokenId: BigNumberish, amount: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    withdraw(tokenId: BigNumberish, amount: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    callStatic: {
        claimRewards(tokenId: BigNumberish, overrides?: CallOverrides): Promise<void>;
        getStakeInfo(staker: string, overrides?: CallOverrides): Promise<[
            BigNumber[],
            BigNumber[],
            BigNumber
        ] & {
            _tokensStaked: BigNumber[];
            _tokenAmounts: BigNumber[];
            _totalRewards: BigNumber;
        }>;
        getStakeInfoForToken(tokenId: BigNumberish, staker: string, overrides?: CallOverrides): Promise<[
            BigNumber,
            BigNumber
        ] & {
            _tokensStaked: BigNumber;
            _rewards: BigNumber;
        }>;
        stake(tokenId: BigNumberish, amount: BigNumberish, overrides?: CallOverrides): Promise<void>;
        withdraw(tokenId: BigNumberish, amount: BigNumberish, overrides?: CallOverrides): Promise<void>;
    };
    filters: {
        "RewardsClaimed(address,uint256)"(staker?: string | null, rewardAmount?: null): RewardsClaimedEventFilter;
        RewardsClaimed(staker?: string | null, rewardAmount?: null): RewardsClaimedEventFilter;
        "TokensStaked(address,uint256,uint256)"(staker?: string | null, tokenId?: BigNumberish | null, amount?: null): TokensStakedEventFilter;
        TokensStaked(staker?: string | null, tokenId?: BigNumberish | null, amount?: null): TokensStakedEventFilter;
        "TokensWithdrawn(address,uint256,uint256)"(staker?: string | null, tokenId?: BigNumberish | null, amount?: null): TokensWithdrawnEventFilter;
        TokensWithdrawn(staker?: string | null, tokenId?: BigNumberish | null, amount?: null): TokensWithdrawnEventFilter;
        "UpdatedDefaultRewardsPerUnitTime(uint256,uint256)"(oldRewardsPerUnitTime?: null, newRewardsPerUnitTime?: null): UpdatedDefaultRewardsPerUnitTimeEventFilter;
        UpdatedDefaultRewardsPerUnitTime(oldRewardsPerUnitTime?: null, newRewardsPerUnitTime?: null): UpdatedDefaultRewardsPerUnitTimeEventFilter;
        "UpdatedDefaultTimeUnit(uint256,uint256)"(oldTimeUnit?: null, newTimeUnit?: null): UpdatedDefaultTimeUnitEventFilter;
        UpdatedDefaultTimeUnit(oldTimeUnit?: null, newTimeUnit?: null): UpdatedDefaultTimeUnitEventFilter;
        "UpdatedRewardsPerUnitTime(uint256,uint256,uint256)"(_tokenId?: BigNumberish | null, oldRewardsPerUnitTime?: null, newRewardsPerUnitTime?: null): UpdatedRewardsPerUnitTimeEventFilter;
        UpdatedRewardsPerUnitTime(_tokenId?: BigNumberish | null, oldRewardsPerUnitTime?: null, newRewardsPerUnitTime?: null): UpdatedRewardsPerUnitTimeEventFilter;
        "UpdatedTimeUnit(uint256,uint256,uint256)"(_tokenId?: BigNumberish | null, oldTimeUnit?: null, newTimeUnit?: null): UpdatedTimeUnitEventFilter;
        UpdatedTimeUnit(_tokenId?: BigNumberish | null, oldTimeUnit?: null, newTimeUnit?: null): UpdatedTimeUnitEventFilter;
    };
    estimateGas: {
        claimRewards(tokenId: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        getStakeInfo(staker: string, overrides?: CallOverrides): Promise<BigNumber>;
        getStakeInfoForToken(tokenId: BigNumberish, staker: string, overrides?: CallOverrides): Promise<BigNumber>;
        stake(tokenId: BigNumberish, amount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        withdraw(tokenId: BigNumberish, amount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
    };
    populateTransaction: {
        claimRewards(tokenId: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        getStakeInfo(staker: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getStakeInfoForToken(tokenId: BigNumberish, staker: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        stake(tokenId: BigNumberish, amount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        withdraw(tokenId: BigNumberish, amount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
    };
}
//# sourceMappingURL=IStaking1155.d.ts.map